.. _coordinates-schemas:

Coordinates Schemas
===================

The current ``coordinates`` schemas:

.. asdf-autoschemas::

   angle-1.0.0
   earthlocation-1.0.0
   latitude-1.0.0
   longitude-1.0.0
   representation-1.0.0
   skycoord-1.0.0
   spectralcoord-1.0.0
